==> vtk6-6.3.0-2-armv6h.pkg.tar.xz: vtk/vtkExtractVOI.java <==
// java wrapper for vtkExtractVOI object
//

package vtk;
import vtk.*;

public class vtkExtractVOI extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVOI_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetVOI(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetVOI_2(id0,id1,id2,id3,id4,id5); }

  private native void SetVOI_3(int id0[]);
  public void SetVOI(int id0[])
    { SetVOI_3(id0); }

  private native int[]  GetVOI_4();
  public int[]  GetVOI()
    { return GetVOI_4(); }

  private native void SetSampleRate_5(int id0,int id1,int id2);
  public void SetSampleRate(int id0,int id1,int id2)
    { SetSampleRate_5(id0,id1,id2); }

  private native void SetSampleRate_6(int id0[]);
  public void SetSampleRate(int id0[])
    { SetSampleRate_6(id0); }

  private native int[]  GetSampleRate_7();
  public int[]  GetSampleRate()
    { return GetSampleRate_7(); }

  private native void SetIncludeBoundary_8(int id0);
  public void SetIncludeBoundary(int id0)
    { SetIncludeBoundary_8(id0); }

  private native int GetIncludeBoundary_9();
  public int GetIncludeBoundary()
    { return GetIncludeBoundary_9(); }

  private native void IncludeBoundaryOn_10();
  public void IncludeBoundaryOn()
    { IncludeBoundaryOn_10(); }

  private native void IncludeBoundaryOff_11();
  public void IncludeBoundaryOff()
    { IncludeBoundaryOff_11(); }

  public vtkExtractVOI() { super(); }

  public vtkExtractVOI(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv6h.pkg.tar.xz: vtk/vtkExtractVOI.java <==
// java wrapper for vtkExtractVOI object
//

package vtk;
import vtk.*;

public class vtkExtractVOI extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVOI_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetVOI(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetVOI_2(id0,id1,id2,id3,id4,id5); }

  private native void SetVOI_3(int id0[]);
  public void SetVOI(int id0[])
    { SetVOI_3(id0); }

  private native int[]  GetVOI_4();
  public int[]  GetVOI()
    { return GetVOI_4(); }

  private native void SetSampleRate_5(int id0,int id1,int id2);
  public void SetSampleRate(int id0,int id1,int id2)
    { SetSampleRate_5(id0,id1,id2); }

  private native void SetSampleRate_6(int id0[]);
  public void SetSampleRate(int id0[])
    { SetSampleRate_6(id0); }

  private native int[]  GetSampleRate_7();
  public int[]  GetSampleRate()
    { return GetSampleRate_7(); }

  private native void SetIncludeBoundary_8(int id0);
  public void SetIncludeBoundary(int id0)
    { SetIncludeBoundary_8(id0); }

  private native int GetIncludeBoundary_9();
  public int GetIncludeBoundary()
    { return GetIncludeBoundary_9(); }

  private native void IncludeBoundaryOn_10();
  public void IncludeBoundaryOn()
    { IncludeBoundaryOn_10(); }

  private native void IncludeBoundaryOff_11();
  public void IncludeBoundaryOff()
    { IncludeBoundaryOff_11(); }

  public vtkExtractVOI() { super(); }

  public vtkExtractVOI(long id) { super(id); }
  public native long   VTKInit();

}
